feast.exceptions — Feast 0.3.2 documentation

# Source code for feast.exceptions

    # Copyright 2019 The Feast Authors
    #
    # Licensed under the Apache License, Version 2.0 (the "License");
    # you may not use this file except in compliance with the License.
    # You may obtain a copy of the License at
    #
    #     https://www.apache.org/licenses/LICENSE-2.0
    #
    # Unless required by applicable law or agreed to in writing, software
    # distributed under the License is distributed on an "AS IS" BASIS,
    # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    # See the License for the specific language governing permissions and
    # limitations under the License.

    def format_grpc_exception(method: str, code: str, details: str) -> str:
        """
        Consistent format for use in printing gRPC exceptions
        """
        return f'{method} failed with code "{code}"\n{details}'